
/* memo.h */

#ifndef MEMO_H
#define MEMO_H

#include <interfaces/iuicontroller.h>

#include <QWidget>
#include <QTreeView>
#include <QTreeWidget>

#include <KAction>

/* ----------------------------------------------------------------------- */

namespace OverviewModule
{

class OverviewPlugin;

/* ----------------------------------------------------------------------- */

class MemoWidget : public QWidget
{
   Q_OBJECT
   public:
      MemoWidget (QWidget* parent, OverviewPlugin* plugin);
      virtual ~MemoWidget ();
      virtual void contextMenuEvent (QContextMenuEvent* e);

   private Q_SLOTS:
      void treeDoubleClick (QTreeWidgetItem* item, int column);

      void jumpToDeclaration ();
      void jumpToDefinition ();
      void jumpToInterface ();
      void jumpToImplementation ();

   public:
      void display ();

   private:
      OverviewPlugin* m_plugin;
      QTreeWidget* m_tree;

      KAction * m_jumpToDeclaration;
      KAction * m_jumpToDefinition;
      KAction * m_jumpToInterface;
      KAction * m_jumpToImplementation;
};

/* ----------------------------------------------------------------------- */

class MemoFactory: public KDevelop::IToolViewFactory
{
   public:
      MemoFactory (OverviewPlugin *plugin) : m_plugin (plugin), m_widget (NULL) {}

      virtual QWidget* create (QWidget *parent = 0)
      {
         m_widget = new MemoWidget (parent, m_plugin);
         return m_widget;
      }

      virtual Qt::DockWidgetArea defaultPosition()
      {
         return Qt::LeftDockWidgetArea;
      }

      virtual QString id() const
      {
         return "org.kdevelop.Overview.Memo";
      }

   private:
      OverviewPlugin * m_plugin;

   public:
      MemoWidget * m_widget;
};

/* ----------------------------------------------------------------------- */

} // end of namespace

#endif // MEMO_H
