
/* navigator.h */

#ifndef NAVIGATOR_H
#define NAVIGATOR_H

#include <interfaces/iuicontroller.h>
#include <language/duchain/ducontext.h>

#include <QWidget>
#include <QTreeView>
#include <QTreeWidget>

/* ----------------------------------------------------------------------- */

namespace OverviewModule
{

class OverviewPlugin;

/* ----------------------------------------------------------------------- */

class NavigatorItem : public QTreeWidgetItem
{
   public:
      KDevelop::DUContextPointer m_cachedContext;
      KDevelop::DeclarationPointer m_cachedDecl;
};

/* ----------------------------------------------------------------------- */

class NavigatorWidget : public QWidget
{
   Q_OBJECT

   public:
      NavigatorWidget (QWidget* parent, OverviewPlugin* plugin);
      virtual ~NavigatorWidget ();
      virtual void contextMenuEvent (QContextMenuEvent* e);

   private Q_SLOTS:
      void documentActivated (KDevelop::IDocument * doc);
      void documentClosed (KDevelop::IDocument * doc);

      void treeDoubleClick (QTreeWidgetItem* item, int column);

      void jumpToSource ();
      void jumpToDeclaration ();
      void jumpToDefinition ();
      void jumpToInterface ();
      void jumpToImplementation ();

   public:
      KDevelop::Declaration * searchDecl (KDevelop::DUContext * context, const QString id);
      KDevelop::Declaration * searchDeclaration (const QString id);
      void show (QTreeWidgetItem * branch, KDevelop::DUContext * context);
      void display ();

   private:
      OverviewPlugin * m_plugin;
      QTreeWidget * m_tree;

      KAction * m_jumpToSource;
      KAction * m_jumpToDeclaration;
      KAction * m_jumpToDefinition;
      KAction * m_jumpToInterface;
      KAction * m_jumpToImplementation;
};

/* ----------------------------------------------------------------------- */

class NavigatorFactory: public KDevelop::IToolViewFactory
{
   public:
      NavigatorFactory (OverviewPlugin *plugin) : m_plugin (plugin), m_widget (NULL) {}

      virtual QWidget* create (QWidget *parent = 0)
      {
         m_widget = new NavigatorWidget (parent, m_plugin);
         return m_widget;
      }

      virtual Qt::DockWidgetArea defaultPosition()
      {
         return Qt::LeftDockWidgetArea;
      }

      virtual QString id() const
      {
         return "org.kdevelop.Overview.Navigator";
      }

   private:
      OverviewPlugin * m_plugin;

   public:
      NavigatorWidget * m_widget;
};

/* ----------------------------------------------------------------------- */

} // end of namespace

#endif // NAVIGATOR_H
