
/* overview.cc */

#include "overview.h"

#include <QPushButton>

#include <kaboutdata.h>
#include <kaction.h>
#include <kpluginfactory.h>
#include <kactioncollection.h>
#include <kdebug.h>

#include <interfaces/icore.h>
#include <interfaces/contextmenuextension.h>
#include <language/duchain/duchainlock.h>
#include <language/interfaces/codecontext.h>
#include <sublime/area.h>
#include <shell/core.h>
#include <shell/uicontroller.h>

#include "navigator.h"
#include "memo.h"
#include "review.h"
#include "trace.h"

#include <iostream>

/* ----------------------------------------------------------------------- */

namespace OverviewModule {

/* ----------------------------------------------------------------------- */

KAboutData aboutData ("overview", // application name
                      "overview", // catalog name
                      ki18n ("Overview Plugin"), // displayable program name
                      "0.1", // version
                      ki18n ("Simple overview plugin"), // short description
                      KAboutData::License_GPL);

K_PLUGIN_FACTORY (OverviewPluginFactory, registerPlugin <OverviewPlugin> (); )
K_EXPORT_PLUGIN (OverviewPluginFactory (aboutData))

/* ----------------------------------------------------------------------- */

OverviewPlugin::OverviewPlugin (QObject *parent, const QVariantList & args) :
   KDevelop::IPlugin (OverviewPluginFactory::componentData(), parent),
   m_mainWindow (NULL),
   m_navigatorFactory (NULL),
   m_memoFactory (NULL),
   m_reviewFactory (NULL),
   m_traceFactory (NULL),
   m_showNavigator (NULL),
   m_showMemo (NULL)
{
   Q_UNUSED(args)

   std::cout << std::endl;
   std::cout << " **** OVERVIEW INIT **** " << std::endl;
   std::cout << std::endl;

   kDebug () << " ---- OVERVIEW INIT ---- ";

   setXMLFile ("overview.rc");

   m_navigatorFactory = new NavigatorFactory (this);
   core()->uiController()->addToolView (i18n("Navigator"), m_navigatorFactory);

   m_memoFactory = new MemoFactory (this);
   core()->uiController()->addToolView (i18n("Memo"), m_memoFactory);

   m_reviewFactory = new ReviewFactory (this);
   core()->uiController()->addToolView ("Review", m_reviewFactory);

   m_traceFactory = new_trace_factory ();
   core()->uiController()->addToolView ("Overview Trace", m_traceFactory);

   KActionCollection * actions = actionCollection ();

   KAction * action = actions->addAction ("overview_run");
   action->setText (i18n ("Overview Plugin"));
   connect (action, SIGNAL (triggered (bool)), this, SLOT (run ()));

   m_showNavigator = actions->addAction("show_navigator");
   m_showNavigator->setText( i18n("Show Navigator") );
   m_showNavigator->setShortcut( Qt::ALT | Qt::SHIFT | Qt::Key_N );
   QObject::connect(m_showNavigator, SIGNAL(triggered(bool)), this, SLOT(showNavigator()));

   m_showMemo = actions->addAction("show_memo");
   m_showMemo->setText( i18n("Show Memo") );
   m_showMemo->setShortcut( Qt::ALT | Qt::SHIFT | Qt::Key_M );
   QObject::connect(m_showMemo, SIGNAL(triggered(bool)), this, SLOT(showMemo()));
}

OverviewPlugin::~OverviewPlugin()
{
}

void OverviewPlugin::createActionsForMainWindow (Sublime::MainWindow * window,
                                                 QString & xmlFile,
                                                 KActionCollection & actions)
{
   m_mainWindow = window;
   /* do not use 'actions' for action definitions, use 'this->actionCollection ()' */
}

void OverviewPlugin::unload()
{
   core()->uiController()->removeToolView(m_navigatorFactory);
   core()->uiController()->removeToolView(m_memoFactory);
   core()->uiController()->removeToolView(m_reviewFactory);
   core()->uiController()->removeToolView(m_traceFactory);
}

KDevelop::ContextMenuExtension OverviewPlugin::contextMenuExtension (KDevelop::Context * context)
{
   KDevelop::ContextMenuExtension menuExt = KDevelop::IPlugin::contextMenuExtension (context);

   menuExt.addAction (KDevelop::ContextMenuExtension::ExtensionGroup, m_showNavigator);

   KDevelop::DeclarationContext *codeContext = dynamic_cast<KDevelop::DeclarationContext*>(context);
   if (codeContext != NULL)
   {
      KDevelop::DUChainReadLocker readLock;
      KDevelop::Declaration * decl (codeContext->declaration().data());

      if (decl!=NULL)
      {
         menuExt.addAction (KDevelop::ContextMenuExtension::ExtensionGroup, m_showMemo);
      }
   }

   return menuExt;
}

/* ----------------------------------------------------------------------- */

void OverviewPlugin::run ()
{
   // std::cout << std::endl;
   // std::cout << " **** OVERVIEW RUN **** " << std::endl;
   // std::cout << std::endl;

   kDebug () << " ---- OVERVIEW RUN ---- ";
}

void OverviewPlugin::showNavigator ()
{
   // std::cout << "**** Show Navigator ****" << std::endl;
   // kDebug (8000) << "---- Show Navigator ----";
   if (m_navigatorFactory->m_widget != NULL)
       m_navigatorFactory->m_widget->display ();
}

void OverviewPlugin::showMemo ()
{
   // std::cout << "**** Show Memo ****" << std::endl;
   // kDebug () << "---- Show Memo ----";
   if (m_memoFactory->m_widget != NULL)
       m_memoFactory->m_widget->display ();
}

/* ----------------------------------------------------------------------- */

// Highlighting Text Styles tab
// kdelibs-4.5.4/kate/utils/kateschema.cpp

} // end of namespace

#include "overview.moc"
