
/* review.h */

#ifndef REVIEW_H
#define REVIEW_H

#include <interfaces/iuicontroller.h>
#include <language/duchain/ducontext.h>

#include <QWidget>
#include <QTreeView>
#include <QTreeWidget>

/* ----------------------------------------------------------------------- */

namespace OverviewModule
{

class OverviewPlugin;

/* ----------------------------------------------------------------------- */

class ReviewItem : public QTreeWidgetItem
{
   public:
      KDevelop::DUContextPointer m_cachedContext;
      KDevelop::DeclarationPointer m_cachedDecl;
};

/* ----------------------------------------------------------------------- */

class ReviewWidget : public QWidget
{
   Q_OBJECT

   public:
      ReviewWidget (QWidget* parent, OverviewPlugin* plugin);
      virtual ~ReviewWidget ();
      virtual void contextMenuEvent (QContextMenuEvent* e);

   private Q_SLOTS:
      void documentActivated (KDevelop::IDocument * doc);
      void documentClosed (KDevelop::IDocument * doc);

      void treeClick (QTreeWidgetItem* item, int column);
      void treeDoubleClick (QTreeWidgetItem* item, int column);

      void selectRange ();
      void jumpToSource ();
      void display ();

   public:
      void showHeader ();
      void show (QTreeWidgetItem * branch, KDevelop::DUContext * context);

   private:
      OverviewPlugin * m_plugin;
      QTreeWidget * m_tree;

      KAction * m_display;
      KAction * m_jumpToSource;
};

/* ----------------------------------------------------------------------- */

class ReviewFactory: public KDevelop::IToolViewFactory
{
   public:
      ReviewFactory (OverviewPlugin *plugin) : m_plugin (plugin), m_widget (NULL) {}

      virtual QWidget* create (QWidget *parent = 0)
      {
         m_widget = new ReviewWidget (parent, m_plugin);
         return m_widget;
      }

      virtual Qt::DockWidgetArea defaultPosition()
      {
         return Qt::LeftDockWidgetArea;
      }

      virtual QString id() const
      {
         return "org.kdevelop.Overview.Review";
      }

   private:
      OverviewPlugin * m_plugin;

   public:
      ReviewWidget * m_widget;
};

/* ----------------------------------------------------------------------- */

} // end of namespace

#endif // REVIEW_H
